Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(583)

Unified Diff: sandbox/src/dep_test.cc

Issue 2819011: TTF: Reenable some disabled tests. (Closed)
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sandbox/src/dep_test.cc
diff --git a/sandbox/src/dep_test.cc b/sandbox/src/dep_test.cc
index 7d57c6e8904c63a008305c3267aa241057ed96fb..62eeb1ff317c4c048c5fd2baa388f14bb7b00de8 100644
--- a/sandbox/src/dep_test.cc
+++ b/sandbox/src/dep_test.cc
@@ -166,8 +166,8 @@ SBOX_TESTS_COMMAND int CheckDepLevel(int argc, wchar_t **argv) {
} // namespace
-// This test is disabled. See bug 1275842
-TEST_F(DepTest, DISABLED_TestDepDisable) {
+// This test fails. See bug 1275842
James Hawkins 2010/06/18 00:32:38 Should we convert that to a crbug?
+TEST_F(DepTest, FAILS_TestDepDisable) {
TestRunner runner(JOB_UNPROTECTED, USER_INTERACTIVE, USER_INTERACTIVE);
runner.SetTimeout(INFINITE);

Powered by Google App Engine
This is Rietveld 408576698